@@ -153,27 +153,36 @@ AddApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ApplicationDetailTypeDef = TypedDict(
-    "ApplicationDetailTypeDef",
+_RequiredApplicationDetailTypeDef = TypedDict(
+    "_RequiredApplicationDetailTypeDef",
     {
         "ApplicationName": str,
         "ApplicationARN": str,
         "ApplicationStatus": ApplicationStatusType,
         "ApplicationVersionId": int,
-        "ApplicationDescription": NotRequired[str],
-        "CreateTimestamp": NotRequired[datetime],
-        "LastUpdateTimestamp": NotRequired[datetime],
-        "InputDescriptions": NotRequired[List["InputDescriptionTypeDef"]],
-        "OutputDescriptions": NotRequired[List["OutputDescriptionTypeDef"]],
-        "ReferenceDataSourceDescriptions": NotRequired[
-            List["ReferenceDataSourceDescriptionTypeDef"]
-        ],
-        "CloudWatchLoggingOptionDescriptions": NotRequired[
-            List["CloudWatchLoggingOptionDescriptionTypeDef"]
-        ],
-        "ApplicationCode": NotRequired[str],
     },
 )
+_OptionalApplicationDetailTypeDef = TypedDict(
+    "_OptionalApplicationDetailTypeDef",
+    {
+        "ApplicationDescription": str,
+        "CreateTimestamp": datetime,
+        "LastUpdateTimestamp": datetime,
+        "InputDescriptions": List["InputDescriptionTypeDef"],
+        "OutputDescriptions": List["OutputDescriptionTypeDef"],
+        "ReferenceDataSourceDescriptions": List["ReferenceDataSourceDescriptionTypeDef"],
+        "CloudWatchLoggingOptionDescriptions": List["CloudWatchLoggingOptionDescriptionTypeDef"],
+        "ApplicationCode": str,
+    },
+    total=False,
+)
+
+
+class ApplicationDetailTypeDef(
+    _RequiredApplicationDetailTypeDef, _OptionalApplicationDetailTypeDef
+):
+    pass
+
 
 ApplicationSummaryTypeDef = TypedDict(
     "ApplicationSummaryTypeDef",
@@ -187,14 +196,13 @@ ApplicationSummaryTypeDef = TypedDict(
 ApplicationUpdateTypeDef = TypedDict(
     "ApplicationUpdateTypeDef",
     {
-        "InputUpdates": NotRequired[Sequence["InputUpdateTypeDef"]],
-        "ApplicationCodeUpdate": NotRequired[str],
-        "OutputUpdates": NotRequired[Sequence["OutputUpdateTypeDef"]],
-        "ReferenceDataSourceUpdates": NotRequired[Sequence["ReferenceDataSourceUpdateTypeDef"]],
-        "CloudWatchLoggingOptionUpdates": NotRequired[
-            Sequence["CloudWatchLoggingOptionUpdateTypeDef"]
-        ],
+        "InputUpdates": Sequence["InputUpdateTypeDef"],
+        "ApplicationCodeUpdate": str,
+        "OutputUpdates": Sequence["OutputUpdateTypeDef"],
+        "ReferenceDataSourceUpdates": Sequence["ReferenceDataSourceUpdateTypeDef"],
+        "CloudWatchLoggingOptionUpdates": Sequence["CloudWatchLoggingOptionUpdateTypeDef"],
     },
+    total=False,
 )
 
 CSVMappingParametersTypeDef = TypedDict(
@@ -205,14 +213,28 @@ CSVMappingParametersTypeDef = TypedDict(
     },
 )
 
-CloudWatchLoggingOptionDescriptionTypeDef = TypedDict(
-    "CloudWatchLoggingOptionDescriptionTypeDef",
+_RequiredCloudWatchLoggingOptionDescriptionTypeDef = TypedDict(
+    "_RequiredCloudWatchLoggingOptionDescriptionTypeDef",
     {
         "LogStreamARN": str,
         "RoleARN": str,
-        "CloudWatchLoggingOptionId": NotRequired[str],
     },
 )
+_OptionalCloudWatchLoggingOptionDescriptionTypeDef = TypedDict(
+    "_OptionalCloudWatchLoggingOptionDescriptionTypeDef",
+    {
+        "CloudWatchLoggingOptionId": str,
+    },
+    total=False,
+)
+
+
+class CloudWatchLoggingOptionDescriptionTypeDef(
+    _RequiredCloudWatchLoggingOptionDescriptionTypeDef,
+    _OptionalCloudWatchLoggingOptionDescriptionTypeDef,
+):
+    pass
+
 
 CloudWatchLoggingOptionTypeDef = TypedDict(
     "CloudWatchLoggingOptionTypeDef",
@@ -222,27 +244,53 @@ CloudWatchLoggingOptionTypeDef = TypedDict(
     },
 )
 
-CloudWatchLoggingOptionUpdateTypeDef = TypedDict(
-    "CloudWatchLoggingOptionUpdateTypeDef",
+_RequiredCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
+    "_RequiredCloudWatchLoggingOptionUpdateTypeDef",
     {
         "CloudWatchLoggingOptionId": str,
-        "LogStreamARNUpdate": NotRequired[str],
-        "RoleARNUpdate": NotRequired[str],
     },
 )
+_OptionalCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
+    "_OptionalCloudWatchLoggingOptionUpdateTypeDef",
+    {
+        "LogStreamARNUpdate": str,
+        "RoleARNUpdate": str,
+    },
+    total=False,
+)
 
-CreateApplicationRequestRequestTypeDef = TypedDict(
-    "CreateApplicationRequestRequestTypeDef",
+
+class CloudWatchLoggingOptionUpdateTypeDef(
+    _RequiredCloudWatchLoggingOptionUpdateTypeDef, _OptionalCloudWatchLoggingOptionUpdateTypeDef
+):
+    pass
+
+
+_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
-        "ApplicationDescription": NotRequired[str],
-        "Inputs": NotRequired[Sequence["InputTypeDef"]],
-        "Outputs": NotRequired[Sequence["OutputTypeDef"]],
-        "CloudWatchLoggingOptions": NotRequired[Sequence["CloudWatchLoggingOptionTypeDef"]],
-        "ApplicationCode": NotRequired[str],
-        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateApplicationRequestRequestTypeDef",
+    {
+        "ApplicationDescription": str,
+        "Inputs": Sequence["InputTypeDef"],
+        "Outputs": Sequence["OutputTypeDef"],
+        "CloudWatchLoggingOptions": Sequence["CloudWatchLoggingOptionTypeDef"],
+        "ApplicationCode": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateApplicationRequestRequestTypeDef(
+    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
+):
+    pass
+
 
 CreateApplicationResponseTypeDef = TypedDict(
     "CreateApplicationResponseTypeDef",
@@ -321,14 +369,13 @@ DestinationSchemaTypeDef = TypedDict(
 DiscoverInputSchemaRequestRequestTypeDef = TypedDict(
     "DiscoverInputSchemaRequestRequestTypeDef",
     {
-        "ResourceARN": NotRequired[str],
-        "RoleARN": NotRequired[str],
-        "InputStartingPositionConfiguration": NotRequired[
-            "InputStartingPositionConfigurationTypeDef"
-        ],
-        "S3Configuration": NotRequired["S3ConfigurationTypeDef"],
-        "InputProcessingConfiguration": NotRequired["InputProcessingConfigurationTypeDef"],
+        "ResourceARN": str,
+        "RoleARN": str,
+        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
+        "S3Configuration": "S3ConfigurationTypeDef",
+        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
     },
+    total=False,
 )
 
 DiscoverInputSchemaResponseTypeDef = TypedDict(
@@ -353,28 +400,26 @@ InputConfigurationTypeDef = TypedDict(
 InputDescriptionTypeDef = TypedDict(
     "InputDescriptionTypeDef",
     {
-        "InputId": NotRequired[str],
-        "NamePrefix": NotRequired[str],
-        "InAppStreamNames": NotRequired[List[str]],
-        "InputProcessingConfigurationDescription": NotRequired[
-            "InputProcessingConfigurationDescriptionTypeDef"
-        ],
-        "KinesisStreamsInputDescription": NotRequired["KinesisStreamsInputDescriptionTypeDef"],
-        "KinesisFirehoseInputDescription": NotRequired["KinesisFirehoseInputDescriptionTypeDef"],
-        "InputSchema": NotRequired["SourceSchemaTypeDef"],
-        "InputParallelism": NotRequired["InputParallelismTypeDef"],
-        "InputStartingPositionConfiguration": NotRequired[
-            "InputStartingPositionConfigurationTypeDef"
-        ],
+        "InputId": str,
+        "NamePrefix": str,
+        "InAppStreamNames": List[str],
+        "InputProcessingConfigurationDescription": "InputProcessingConfigurationDescriptionTypeDef",
+        "KinesisStreamsInputDescription": "KinesisStreamsInputDescriptionTypeDef",
+        "KinesisFirehoseInputDescription": "KinesisFirehoseInputDescriptionTypeDef",
+        "InputSchema": "SourceSchemaTypeDef",
+        "InputParallelism": "InputParallelismTypeDef",
+        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
     },
+    total=False,
 )
 
 InputLambdaProcessorDescriptionTypeDef = TypedDict(
     "InputLambdaProcessorDescriptionTypeDef",
     {
-        "ResourceARN": NotRequired[str],
-        "RoleARN": NotRequired[str],
+        "ResourceARN": str,
+        "RoleARN": str,
     },
+    total=False,
 )
 
 InputLambdaProcessorTypeDef = TypedDict(
@@ -388,30 +433,34 @@ InputLambdaProcessorTypeDef = TypedDict(
 InputLambdaProcessorUpdateTypeDef = TypedDict(
     "InputLambdaProcessorUpdateTypeDef",
     {
-        "ResourceARNUpdate": NotRequired[str],
-        "RoleARNUpdate": NotRequired[str],
+        "ResourceARNUpdate": str,
+        "RoleARNUpdate": str,
     },
+    total=False,
 )
 
 InputParallelismTypeDef = TypedDict(
     "InputParallelismTypeDef",
     {
-        "Count": NotRequired[int],
+        "Count": int,
     },
+    total=False,
 )
 
 InputParallelismUpdateTypeDef = TypedDict(
     "InputParallelismUpdateTypeDef",
     {
-        "CountUpdate": NotRequired[int],
+        "CountUpdate": int,
     },
+    total=False,
 )
 
 InputProcessingConfigurationDescriptionTypeDef = TypedDict(
     "InputProcessingConfigurationDescriptionTypeDef",
     {
-        "InputLambdaProcessorDescription": NotRequired["InputLambdaProcessorDescriptionTypeDef"],
+        "InputLambdaProcessorDescription": "InputLambdaProcessorDescriptionTypeDef",
     },
+    total=False,
 )
 
 InputProcessingConfigurationTypeDef = TypedDict(
@@ -431,45 +480,67 @@ InputProcessingConfigurationUpdateTypeDef = TypedDict(
 InputSchemaUpdateTypeDef = TypedDict(
     "InputSchemaUpdateTypeDef",
     {
-        "RecordFormatUpdate": NotRequired["RecordFormatTypeDef"],
-        "RecordEncodingUpdate": NotRequired[str],
-        "RecordColumnUpdates": NotRequired[Sequence["RecordColumnTypeDef"]],
+        "RecordFormatUpdate": "RecordFormatTypeDef",
+        "RecordEncodingUpdate": str,
+        "RecordColumnUpdates": Sequence["RecordColumnTypeDef"],
     },
+    total=False,
 )
 
 InputStartingPositionConfigurationTypeDef = TypedDict(
     "InputStartingPositionConfigurationTypeDef",
     {
-        "InputStartingPosition": NotRequired[InputStartingPositionType],
+        "InputStartingPosition": InputStartingPositionType,
     },
+    total=False,
 )
 
-InputTypeDef = TypedDict(
-    "InputTypeDef",
+_RequiredInputTypeDef = TypedDict(
+    "_RequiredInputTypeDef",
     {
         "NamePrefix": str,
         "InputSchema": "SourceSchemaTypeDef",
-        "InputProcessingConfiguration": NotRequired["InputProcessingConfigurationTypeDef"],
-        "KinesisStreamsInput": NotRequired["KinesisStreamsInputTypeDef"],
-        "KinesisFirehoseInput": NotRequired["KinesisFirehoseInputTypeDef"],
-        "InputParallelism": NotRequired["InputParallelismTypeDef"],
     },
 )
+_OptionalInputTypeDef = TypedDict(
+    "_OptionalInputTypeDef",
+    {
+        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
+        "KinesisStreamsInput": "KinesisStreamsInputTypeDef",
+        "KinesisFirehoseInput": "KinesisFirehoseInputTypeDef",
+        "InputParallelism": "InputParallelismTypeDef",
+    },
+    total=False,
+)
 
-InputUpdateTypeDef = TypedDict(
-    "InputUpdateTypeDef",
+
+class InputTypeDef(_RequiredInputTypeDef, _OptionalInputTypeDef):
+    pass
+
+
+_RequiredInputUpdateTypeDef = TypedDict(
+    "_RequiredInputUpdateTypeDef",
     {
         "InputId": str,
-        "NamePrefixUpdate": NotRequired[str],
-        "InputProcessingConfigurationUpdate": NotRequired[
-            "InputProcessingConfigurationUpdateTypeDef"
-        ],
-        "KinesisStreamsInputUpdate": NotRequired["KinesisStreamsInputUpdateTypeDef"],
-        "KinesisFirehoseInputUpdate": NotRequired["KinesisFirehoseInputUpdateTypeDef"],
-        "InputSchemaUpdate": NotRequired["InputSchemaUpdateTypeDef"],
-        "InputParallelismUpdate": NotRequired["InputParallelismUpdateTypeDef"],
     },
 )
+_OptionalInputUpdateTypeDef = TypedDict(
+    "_OptionalInputUpdateTypeDef",
+    {
+        "NamePrefixUpdate": str,
+        "InputProcessingConfigurationUpdate": "InputProcessingConfigurationUpdateTypeDef",
+        "KinesisStreamsInputUpdate": "KinesisStreamsInputUpdateTypeDef",
+        "KinesisFirehoseInputUpdate": "KinesisFirehoseInputUpdateTypeDef",
+        "InputSchemaUpdate": "InputSchemaUpdateTypeDef",
+        "InputParallelismUpdate": "InputParallelismUpdateTypeDef",
+    },
+    total=False,
+)
+
+
+class InputUpdateTypeDef(_RequiredInputUpdateTypeDef, _OptionalInputUpdateTypeDef):
+    pass
+
 
 JSONMappingParametersTypeDef = TypedDict(
     "JSONMappingParametersTypeDef",
@@ -481,9 +552,10 @@ JSONMappingParametersTypeDef = TypedDict(
 KinesisFirehoseInputDescriptionTypeDef = TypedDict(
     "KinesisFirehoseInputDescriptionTypeDef",
     {
-        "ResourceARN": NotRequired[str],
-        "RoleARN": NotRequired[str],
+        "ResourceARN": str,
+        "RoleARN": str,
     },
+    total=False,
 )
 
 KinesisFirehoseInputTypeDef = TypedDict(
@@ -497,17 +569,19 @@ KinesisFirehoseInputTypeDef = TypedDict(
 KinesisFirehoseInputUpdateTypeDef = TypedDict(
     "KinesisFirehoseInputUpdateTypeDef",
     {
-        "ResourceARNUpdate": NotRequired[str],
-        "RoleARNUpdate": NotRequired[str],
+        "ResourceARNUpdate": str,
+        "RoleARNUpdate": str,
     },
+    total=False,
 )
 
 KinesisFirehoseOutputDescriptionTypeDef = TypedDict(
     "KinesisFirehoseOutputDescriptionTypeDef",
     {
-        "ResourceARN": NotRequired[str],
-        "RoleARN": NotRequired[str],
+        "ResourceARN": str,
+        "RoleARN": str,
     },
+    total=False,
 )
 
 KinesisFirehoseOutputTypeDef = TypedDict(
@@ -521,17 +595,19 @@ KinesisFirehoseOutputTypeDef = TypedDict(
 KinesisFirehoseOutputUpdateTypeDef = TypedDict(
     "KinesisFirehoseOutputUpdateTypeDef",
     {
-        "ResourceARNUpdate": NotRequired[str],
-        "RoleARNUpdate": NotRequired[str],
+        "ResourceARNUpdate": str,
+        "RoleARNUpdate": str,
     },
+    total=False,
 )
 
 KinesisStreamsInputDescriptionTypeDef = TypedDict(
     "KinesisStreamsInputDescriptionTypeDef",
     {
-        "ResourceARN": NotRequired[str],
-        "RoleARN": NotRequired[str],
+        "ResourceARN": str,
+        "RoleARN": str,
     },
+    total=False,
 )
 
 KinesisStreamsInputTypeDef = TypedDict(
@@ -545,17 +621,19 @@ KinesisStreamsInputTypeDef = TypedDict(
 KinesisStreamsInputUpdateTypeDef = TypedDict(
     "KinesisStreamsInputUpdateTypeDef",
     {
-        "ResourceARNUpdate": NotRequired[str],
-        "RoleARNUpdate": NotRequired[str],
+        "ResourceARNUpdate": str,
+        "RoleARNUpdate": str,
     },
+    total=False,
 )
 
 KinesisStreamsOutputDescriptionTypeDef = TypedDict(
     "KinesisStreamsOutputDescriptionTypeDef",
     {
-        "ResourceARN": NotRequired[str],
-        "RoleARN": NotRequired[str],
+        "ResourceARN": str,
+        "RoleARN": str,
     },
+    total=False,
 )
 
 KinesisStreamsOutputTypeDef = TypedDict(
@@ -569,17 +647,19 @@ KinesisStreamsOutputTypeDef = TypedDict(
 KinesisStreamsOutputUpdateTypeDef = TypedDict(
     "KinesisStreamsOutputUpdateTypeDef",
     {
-        "ResourceARNUpdate": NotRequired[str],
-        "RoleARNUpdate": NotRequired[str],
+        "ResourceARNUpdate": str,
+        "RoleARNUpdate": str,
     },
+    total=False,
 )
 
 LambdaOutputDescriptionTypeDef = TypedDict(
     "LambdaOutputDescriptionTypeDef",
     {
-        "ResourceARN": NotRequired[str],
-        "RoleARN": NotRequired[str],
+        "ResourceARN": str,
+        "RoleARN": str,
     },
+    total=False,
 )
 
 LambdaOutputTypeDef = TypedDict(
@@ -593,17 +673,19 @@ LambdaOutputTypeDef = TypedDict(
 LambdaOutputUpdateTypeDef = TypedDict(
     "LambdaOutputUpdateTypeDef",
     {
-        "ResourceARNUpdate": NotRequired[str],
-        "RoleARNUpdate": NotRequired[str],
+        "ResourceARNUpdate": str,
+        "RoleARNUpdate": str,
     },
+    total=False,
 )
 
 ListApplicationsRequestRequestTypeDef = TypedDict(
     "ListApplicationsRequestRequestTypeDef",
     {
-        "Limit": NotRequired[int],
-        "ExclusiveStartApplicationName": NotRequired[str],
+        "Limit": int,
+        "ExclusiveStartApplicationName": str,
     },
+    total=False,
 )
 
 ListApplicationsResponseTypeDef = TypedDict(
@@ -633,91 +715,176 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 MappingParametersTypeDef = TypedDict(
     "MappingParametersTypeDef",
     {
-        "JSONMappingParameters": NotRequired["JSONMappingParametersTypeDef"],
-        "CSVMappingParameters": NotRequired["CSVMappingParametersTypeDef"],
+        "JSONMappingParameters": "JSONMappingParametersTypeDef",
+        "CSVMappingParameters": "CSVMappingParametersTypeDef",
     },
+    total=False,
 )
 
 OutputDescriptionTypeDef = TypedDict(
     "OutputDescriptionTypeDef",
     {
-        "OutputId": NotRequired[str],
-        "Name": NotRequired[str],
-        "KinesisStreamsOutputDescription": NotRequired["KinesisStreamsOutputDescriptionTypeDef"],
-        "KinesisFirehoseOutputDescription": NotRequired["KinesisFirehoseOutputDescriptionTypeDef"],
-        "LambdaOutputDescription": NotRequired["LambdaOutputDescriptionTypeDef"],
-        "DestinationSchema": NotRequired["DestinationSchemaTypeDef"],
+        "OutputId": str,
+        "Name": str,
+        "KinesisStreamsOutputDescription": "KinesisStreamsOutputDescriptionTypeDef",
+        "KinesisFirehoseOutputDescription": "KinesisFirehoseOutputDescriptionTypeDef",
+        "LambdaOutputDescription": "LambdaOutputDescriptionTypeDef",
+        "DestinationSchema": "DestinationSchemaTypeDef",
     },
+    total=False,
 )
 
-OutputTypeDef = TypedDict(
-    "OutputTypeDef",
+_RequiredOutputTypeDef = TypedDict(
+    "_RequiredOutputTypeDef",
     {
         "Name": str,
         "DestinationSchema": "DestinationSchemaTypeDef",
-        "KinesisStreamsOutput": NotRequired["KinesisStreamsOutputTypeDef"],
-        "KinesisFirehoseOutput": NotRequired["KinesisFirehoseOutputTypeDef"],
-        "LambdaOutput": NotRequired["LambdaOutputTypeDef"],
     },
 )
+_OptionalOutputTypeDef = TypedDict(
+    "_OptionalOutputTypeDef",
+    {
+        "KinesisStreamsOutput": "KinesisStreamsOutputTypeDef",
+        "KinesisFirehoseOutput": "KinesisFirehoseOutputTypeDef",
+        "LambdaOutput": "LambdaOutputTypeDef",
+    },
+    total=False,
+)
 
-OutputUpdateTypeDef = TypedDict(
-    "OutputUpdateTypeDef",
+
+class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
+    pass
+
+
+_RequiredOutputUpdateTypeDef = TypedDict(
+    "_RequiredOutputUpdateTypeDef",
     {
         "OutputId": str,
-        "NameUpdate": NotRequired[str],
-        "KinesisStreamsOutputUpdate": NotRequired["KinesisStreamsOutputUpdateTypeDef"],
-        "KinesisFirehoseOutputUpdate": NotRequired["KinesisFirehoseOutputUpdateTypeDef"],
-        "LambdaOutputUpdate": NotRequired["LambdaOutputUpdateTypeDef"],
-        "DestinationSchemaUpdate": NotRequired["DestinationSchemaTypeDef"],
     },
 )
+_OptionalOutputUpdateTypeDef = TypedDict(
+    "_OptionalOutputUpdateTypeDef",
+    {
+        "NameUpdate": str,
+        "KinesisStreamsOutputUpdate": "KinesisStreamsOutputUpdateTypeDef",
+        "KinesisFirehoseOutputUpdate": "KinesisFirehoseOutputUpdateTypeDef",
+        "LambdaOutputUpdate": "LambdaOutputUpdateTypeDef",
+        "DestinationSchemaUpdate": "DestinationSchemaTypeDef",
+    },
+    total=False,
+)
 
-RecordColumnTypeDef = TypedDict(
-    "RecordColumnTypeDef",
+
+class OutputUpdateTypeDef(_RequiredOutputUpdateTypeDef, _OptionalOutputUpdateTypeDef):
+    pass
+
+
+_RequiredRecordColumnTypeDef = TypedDict(
+    "_RequiredRecordColumnTypeDef",
     {
         "Name": str,
         "SqlType": str,
-        "Mapping": NotRequired[str],
     },
 )
+_OptionalRecordColumnTypeDef = TypedDict(
+    "_OptionalRecordColumnTypeDef",
+    {
+        "Mapping": str,
+    },
+    total=False,
+)
 
-RecordFormatTypeDef = TypedDict(
-    "RecordFormatTypeDef",
+
+class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTypeDef):
+    pass
+
+
+_RequiredRecordFormatTypeDef = TypedDict(
+    "_RequiredRecordFormatTypeDef",
     {
         "RecordFormatType": RecordFormatTypeType,
-        "MappingParameters": NotRequired["MappingParametersTypeDef"],
     },
 )
+_OptionalRecordFormatTypeDef = TypedDict(
+    "_OptionalRecordFormatTypeDef",
+    {
+        "MappingParameters": "MappingParametersTypeDef",
+    },
+    total=False,
+)
 
-ReferenceDataSourceDescriptionTypeDef = TypedDict(
-    "ReferenceDataSourceDescriptionTypeDef",
+
+class RecordFormatTypeDef(_RequiredRecordFormatTypeDef, _OptionalRecordFormatTypeDef):
+    pass
+
+
+_RequiredReferenceDataSourceDescriptionTypeDef = TypedDict(
+    "_RequiredReferenceDataSourceDescriptionTypeDef",
     {
         "ReferenceId": str,
         "TableName": str,
         "S3ReferenceDataSourceDescription": "S3ReferenceDataSourceDescriptionTypeDef",
-        "ReferenceSchema": NotRequired["SourceSchemaTypeDef"],
     },
 )
+_OptionalReferenceDataSourceDescriptionTypeDef = TypedDict(
+    "_OptionalReferenceDataSourceDescriptionTypeDef",
+    {
+        "ReferenceSchema": "SourceSchemaTypeDef",
+    },
+    total=False,
+)
 
-ReferenceDataSourceTypeDef = TypedDict(
-    "ReferenceDataSourceTypeDef",
+
+class ReferenceDataSourceDescriptionTypeDef(
+    _RequiredReferenceDataSourceDescriptionTypeDef, _OptionalReferenceDataSourceDescriptionTypeDef
+):
+    pass
+
+
+_RequiredReferenceDataSourceTypeDef = TypedDict(
+    "_RequiredReferenceDataSourceTypeDef",
     {
         "TableName": str,
         "ReferenceSchema": "SourceSchemaTypeDef",
-        "S3ReferenceDataSource": NotRequired["S3ReferenceDataSourceTypeDef"],
     },
 )
+_OptionalReferenceDataSourceTypeDef = TypedDict(
+    "_OptionalReferenceDataSourceTypeDef",
+    {
+        "S3ReferenceDataSource": "S3ReferenceDataSourceTypeDef",
+    },
+    total=False,
+)
 
-ReferenceDataSourceUpdateTypeDef = TypedDict(
-    "ReferenceDataSourceUpdateTypeDef",
+
+class ReferenceDataSourceTypeDef(
+    _RequiredReferenceDataSourceTypeDef, _OptionalReferenceDataSourceTypeDef
+):
+    pass
+
+
+_RequiredReferenceDataSourceUpdateTypeDef = TypedDict(
+    "_RequiredReferenceDataSourceUpdateTypeDef",
     {
         "ReferenceId": str,
-        "TableNameUpdate": NotRequired[str],
-        "S3ReferenceDataSourceUpdate": NotRequired["S3ReferenceDataSourceUpdateTypeDef"],
-        "ReferenceSchemaUpdate": NotRequired["SourceSchemaTypeDef"],
     },
 )
+_OptionalReferenceDataSourceUpdateTypeDef = TypedDict(
+    "_OptionalReferenceDataSourceUpdateTypeDef",
+    {
+        "TableNameUpdate": str,
+        "S3ReferenceDataSourceUpdate": "S3ReferenceDataSourceUpdateTypeDef",
+        "ReferenceSchemaUpdate": "SourceSchemaTypeDef",
+    },
+    total=False,
+)
+
+
+class ReferenceDataSourceUpdateTypeDef(
+    _RequiredReferenceDataSourceUpdateTypeDef, _OptionalReferenceDataSourceUpdateTypeDef
+):
+    pass
+
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -760,20 +927,32 @@ S3ReferenceDataSourceTypeDef = TypedDict(
 S3ReferenceDataSourceUpdateTypeDef = TypedDict(
     "S3ReferenceDataSourceUpdateTypeDef",
     {
-        "BucketARNUpdate": NotRequired[str],
-        "FileKeyUpdate": NotRequired[str],
-        "ReferenceRoleARNUpdate": NotRequired[str],
+        "BucketARNUpdate": str,
+        "FileKeyUpdate": str,
+        "ReferenceRoleARNUpdate": str,
     },
+    total=False,
 )
 
-SourceSchemaTypeDef = TypedDict(
-    "SourceSchemaTypeDef",
+_RequiredSourceSchemaTypeDef = TypedDict(
+    "_RequiredSourceSchemaTypeDef",
     {
         "RecordFormat": "RecordFormatTypeDef",
         "RecordColumns": Sequence["RecordColumnTypeDef"],
-        "RecordEncoding": NotRequired[str],
     },
 )
+_OptionalSourceSchemaTypeDef = TypedDict(
+    "_OptionalSourceSchemaTypeDef",
+    {
+        "RecordEncoding": str,
+    },
+    total=False,
+)
+
+
+class SourceSchemaTypeDef(_RequiredSourceSchemaTypeDef, _OptionalSourceSchemaTypeDef):
+    pass
+
 
 StartApplicationRequestRequestTypeDef = TypedDict(
     "StartApplicationRequestRequestTypeDef",
@@ -798,13 +977,24 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-TagTypeDef = TypedDict(
-    "TagTypeDef",
+_RequiredTagTypeDef = TypedDict(
+    "_RequiredTagTypeDef",
     {
         "Key": str,
-        "Value": NotRequired[str],
     },
 )
+_OptionalTagTypeDef = TypedDict(
+    "_OptionalTagTypeDef",
+    {
+        "Value": str,
+    },
+    total=False,
+)
+
+
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+    pass
+
 
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
